Enum IdParseError
#[non_exhaustive]pub enum IdParseError {
Empty,
InvalidCharacters,
InvalidMatrixId(MatrixIdError),
InvalidMatrixToUri(MatrixToError),
InvalidMatrixUri(MatrixUriError),
InvalidMxcUri(MxcUriError),
InvalidVoipVersionId(VoipVersionIdError),
InvalidServerName,
InvalidUtf8,
MaximumLengthExceeded,
MissingColon,
MissingLeadingSigil,
}Expand description
An error encountered when trying to parse an invalid ID string.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Empty
The identifier or a required part of it is empty.
InvalidCharacters
The identifier contains invalid characters.
InvalidMatrixId(MatrixIdError)
The string isn’t a valid Matrix ID.
InvalidMatrixToUri(MatrixToError)
The string isn’t a valid Matrix.to URI.
InvalidMatrixUri(MatrixUriError)
The string isn’t a valid Matrix URI.
InvalidMxcUri(MxcUriError)
The mxc:// isn’t a valid Matrix Content URI.
InvalidVoipVersionId(VoipVersionIdError)
The value isn’t a valid VoIP version Id.
InvalidServerName
The server name part of the the ID string is not a valid server name.
InvalidUtf8
The string isn’t valid UTF-8.
MaximumLengthExceeded
The ID exceeds 255 bytes (or 32 codepoints for a room version ID).
MissingColon
The ID is missing the colon delimiter between localpart and server name, or between key algorithm and key name / version.
MissingLeadingSigil
The ID is missing the correct leading sigil.