pub struct HomeserverCapabilities { /* private fields */ }Expand description
Helper to check what Capabilities are supported by the homeserver.
Spec: https://spec.matrix.org/latest/client-server-api/#capabilities-negotiation
Implementations
Sourceimpl HomeserverCapabilities
impl HomeserverCapabilities
Sourcepub fn new(client: Client) -> Self
pub fn new(client: Client) -> Self
Creates a new HomeserverCapabilities instance.
Sourcepub async fn refresh(&self) -> Result<()>
pub async fn refresh(&self) -> Result<()>
Forces a refresh of the cached value using the /capabilities endpoint.
Sourcepub async fn can_change_password(&self) -> Result<bool>
pub async fn can_change_password(&self) -> Result<bool>
Returns whether the user can change their password or not.
Sourcepub async fn can_change_displayname(&self) -> Result<bool>
pub async fn can_change_displayname(&self) -> Result<bool>
Returns whether the user can change their display name or not.
This will first check the m.profile_fields capability and use it if
present, or fall back to m.set_displayname otherwise.
Spec: https://spec.matrix.org/latest/client-server-api/#mset_displayname-capability
Sourcepub async fn can_change_avatar(&self) -> Result<bool>
pub async fn can_change_avatar(&self) -> Result<bool>
Returns whether the user can change their avatar or not.
This will first check the m.profile_fields capability and use it if
present, or fall back to m.set_avatar_url otherwise.
Spec: https://spec.matrix.org/latest/client-server-api/#mset_avatar_url-capability
Sourcepub async fn can_change_thirdparty_ids(&self) -> Result<bool>
pub async fn can_change_thirdparty_ids(&self) -> Result<bool>
Returns whether the user can add, remove, or change 3PID associations on their account.
Spec: https://spec.matrix.org/latest/client-server-api/#m3pid_changes-capability
Sourcepub async fn can_get_login_token(&self) -> Result<bool>
pub async fn can_get_login_token(&self) -> Result<bool>
Returns whether the user is able to use POST /login/get_token to
generate single-use, time-limited tokens to log unauthenticated
clients into their account.
When not listed, clients SHOULD assume the user is unable to generate tokens.
Spec: https://spec.matrix.org/latest/client-server-api/#mget_login_token-capability
Sourcepub async fn extended_profile_fields(&self) -> Result<ProfileFieldsCapability>
pub async fn extended_profile_fields(&self) -> Result<ProfileFieldsCapability>
Returns which profile fields the user is able to change.
Spec: https://spec.matrix.org/latest/client-server-api/#mprofile_fields-capability
Sourcepub async fn room_versions(&self) -> Result<RoomVersionsCapability>
pub async fn room_versions(&self) -> Result<RoomVersionsCapability>
Returns the room versions supported by the server.
Spec: https://spec.matrix.org/latest/client-server-api/#mroom_versions-capability
Sourcepub async fn account_moderation(&self) -> Result<AccountModerationCapability>
pub async fn account_moderation(&self) -> Result<AccountModerationCapability>
Returns whether the user can perform account moderation actions.
Sourcepub async fn forgets_room_when_leaving(&self) -> Result<bool>
pub async fn forgets_room_when_leaving(&self) -> Result<bool>
Returns whether or not the server automatically forgets rooms which the user has left.
Spec: https://spec.matrix.org/latest/client-server-api/#mforget_forced_upon_leave-capability