RoomInfo

Struct RoomInfo 

pub struct RoomInfo { /* private fields */ }
The underlying pure data structure for joined and left rooms.

Holds all the info needed to persist a room into the state store.

Implementations

Source

impl RoomInfo

pub fn mark_as_joined(&mut self)

Mark this Room as joined.

pub fn mark_as_left(&mut self)

Mark this Room as left.

pub fn mark_as_invited(&mut self)

Mark this Room as invited.

pub fn mark_as_knocked(&mut self)

Mark this Room as knocked.

pub fn mark_as_banned(&mut self)

Mark this Room as banned.

pub fn set_state(&mut self, room_state: RoomState)

Set the membership RoomState of this Room

pub fn mark_members_synced(&mut self)

Mark this Room as having all the members synced.

pub fn mark_members_missing(&mut self)

Mark this Room as still missing member information.

pub fn are_members_synced(&self) -> bool

Returns whether the room members are synced.

pub fn mark_state_partially_synced(&mut self)

Mark this Room as still missing some state information.

pub fn mark_state_fully_synced(&mut self)

Mark this Room as still having all state synced.

pub fn mark_state_not_synced(&mut self)

Mark this Room as still having no state synced.

pub fn mark_encryption_state_synced(&mut self)

Mark this Room as having the encryption state synced.

pub fn mark_encryption_state_missing(&mut self)

Mark this Room as still missing encryption state information.

pub fn set_prev_batch(&mut self, prev_batch: Option<&str>) -> bool

Set the prev_batch-token. Returns whether the token has differed and thus has been upgraded: false means no update was applied as the were the same

pub fn state(&self) -> RoomState

Returns the state this room is in.

pub fn encryption_state(&self) -> EncryptionState

Available on non-crate feature experimental-encrypted-state-events only.

Returns the encryption state of this room.

pub fn set_encryption_event( &mut self, event: Option<PossiblyRedactedRoomEncryptionEventContent>, )

Set the encryption event content in this room.

pub fn handle_encryption_state( &mut self, requested_required_states: &[(StateEventType, String)], )

Handle the encryption state.

pub fn handle_state_event( &mut self, raw_event: &mut RawStateEventWithKeys<AnySyncStateEvent>, ) -> bool

Handle the given state event.

Returns true if the event modified the info, false otherwise.

pub fn handle_stripped_state_event( &mut self, raw_event: &mut RawStateEventWithKeys<AnyStrippedStateEvent>, ) -> bool

Handle the given stripped state event.

Returns true if the event modified the info, false otherwise.

pub fn handle_redaction( &mut self, event: &SyncRoomRedactionEvent, _raw: &Raw<SyncRoomRedactionEvent>, )

Handle the given redaction.

pub fn avatar_url(&self) -> Option<&MxcUri>

Returns the current room avatar.

pub fn update_avatar(&mut self, url: Option<OwnedMxcUri>)

Update the room avatar.

pub fn avatar_info(&self) -> Option<&ImageInfo>

Returns information about the current room avatar.

pub fn update_notification_count( &mut self, notification_counts: UnreadNotificationsCount, )

Update the notifications count.

pub fn update_from_ruma_summary(&mut self, summary: &RoomSummary) -> bool

Update the RoomSummary from a Ruma RoomSummary.

Returns true if any field has been updated, false otherwise.

pub fn heroes(&self) -> &[RoomHero]

The heroes for this room.

pub fn active_members_count(&self) -> u64

The number of active members (invited + joined) in the room.

The return value is saturated at u64::MAX.

pub fn invited_members_count(&self) -> u64

The number of invited members in the room

pub fn joined_members_count(&self) -> u64

The number of joined members in the room

pub fn canonical_alias(&self) -> Option<&RoomAliasId>

Get the canonical alias of this room.

pub fn alt_aliases(&self) -> &[OwnedRoomAliasId]

Get the alternative aliases of this room.

pub fn room_id(&self) -> &RoomId

Get the room ID of this room.

pub fn room_version(&self) -> Option<&RoomVersionId>

Get the room version of this room.

pub fn room_version_rules_or_default(&self) -> RoomVersionRules

Get the room version rules of this room, or a sensible default.

Will warn (at most once) if the room create event is missing from this RoomInfo or if the room version is unsupported.

pub fn room_type(&self) -> Option<&RoomType>

Get the room type of this room.

pub fn creators(&self) -> Option<Vec<OwnedUserId>>

Get the creators of this room.

pub fn history_visibility(&self) -> Option<&HistoryVisibility>

Returns the history visibility for this room.

Returns None if the event was never seen during sync.

pub fn history_visibility_or_default(&self) -> &HistoryVisibility

Returns the history visibility for this room, or a sensible default.

Returns Shared, the default specified by the spec, when the event is missing.

pub fn join_rule(&self) -> Option<&JoinRule>

Return the join rule for this room, if the m.room.join_rules event is available.

pub fn service_members(&self) -> Option<&BTreeSet<OwnedUserId>>

Return the service members for this room if the m.member_hints event is available

pub fn name(&self) -> Option<&str>

Get the name of this room.

pub fn create(&self) -> Option<&RoomCreateWithCreatorEventContent>

Get the content of the m.room.create event if any.

pub fn tombstone(&self) -> Option<&PossiblyRedactedRoomTombstoneEventContent>

Get the content of the m.room.tombstone event if any.

pub fn topic(&self) -> Option<&str>

Returns the topic for this room, if set.

pub fn has_active_room_call(&self) -> bool

Is there a non expired membership with application “m.call” and scope “m.room” in this room.

pub fn active_room_call_consensus_intent(&self) -> CallIntentConsensus

Get the call intent consensus for the current call, based on what members are advertising.

This provides detailed information about the consensus state (is it an audio or video call), including whether it’s full (all members agree) or partial (only some members advertise), allowing callers to distinguish between different levels of consensus.

Returns
pub fn active_room_call_participants(&self) -> Vec<OwnedUserId>

Returns a Vec of userId’s that participate in the room call.

matrix_rtc memberships with application “m.call” and scope “m.room” are considered. A user can occur twice if they join with two devices. convert to a set depending if the different users are required or the amount of sessions.

The vector is ordered by oldest membership user to newest.

pub fn set_latest_event(&mut self, new_value: LatestEventValue)

Sets the new LatestEventValue.

pub fn update_recency_stamp(&mut self, stamp: RoomRecencyStamp)

Updates the recency stamp of this room.

Please read Self::recency_stamp to learn more.

pub fn pinned_event_ids(&self) -> Option<Vec<OwnedEventId>>

Returns the current pinned event ids for this room.

pub fn is_pinned_event(&self, event_id: &EventId) -> bool

Checks if an EventId is currently pinned. It avoids having to clone the whole list of event ids to check a single value.

Returns true if the provided event_id is pinned, false otherwise.

pub fn read_receipts(&self) -> &RoomReadReceipts

Returns the computed read receipts for this room.

pub fn set_read_receipts(&mut self, read_receipts: RoomReadReceipts)

Set the computed read receipts for this room.