RoomMemberships

Struct RoomMemberships 

pub struct RoomMemberships(/* private fields */);
Room membership filter as a bitset.

Note that RoomMemberships::empty() doesn’t filter the results and RoomMemberships::all() filters out unknown memberships.

Implementations

Source

impl RoomMemberships

pub const JOIN: RoomMemberships

The member joined the room.

pub const INVITE: RoomMemberships

The member was invited to the room.

pub const KNOCK: RoomMemberships

The member requested to join the room.

pub const LEAVE: RoomMemberships

The member left the room.

pub const BAN: RoomMemberships

The member was banned.

pub const ACTIVE: RoomMemberships

The member is active in the room (i.e. joined or invited).

Source

impl RoomMemberships

pub const fn empty() -> RoomMemberships

Get a flags value with all bits unset.

pub const fn all() -> RoomMemberships

Get a flags value with all known bits set.

pub const fn bits(&self) -> u16

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u16) -> Option<RoomMemberships>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u16) -> RoomMemberships

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u16) -> RoomMemberships

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<RoomMemberships>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: RoomMemberships) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: RoomMemberships) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: RoomMemberships)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: RoomMemberships)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: RoomMemberships)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: RoomMemberships, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: RoomMemberships) -> RoomMemberships

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: RoomMemberships) -> RoomMemberships

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: RoomMemberships) -> RoomMemberships

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference( self, other: RoomMemberships, ) -> RoomMemberships

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> RoomMemberships

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl RoomMemberships

pub const fn iter(&self) -> Iter<RoomMemberships>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<RoomMemberships>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl RoomMemberships

pub fn matches(&self, membership: &MembershipState) -> bool

Whether the given membership matches this RoomMemberships.

pub fn as_vec(&self) -> Vec<MembershipState>

Get this RoomMemberships as a list of matching [MembershipState]s.