pub struct ToDeviceMessage {
pub raw: Raw<AnyToDeviceEvent>,
pub encryption_info: Option<EncryptionInfo>,
}Expand description
A custom to-device message received by the client.
Yielded by Client::subscribe_to_custom_to_device_messages.
Fields
raw: Raw<AnyToDeviceEvent>The event as it was received, decrypted if it was sent encrypted.
encryption_info: Option<EncryptionInfo>The encryption data of this message, if it was sent encrypted, or None
if it arrived in the clear.
When present, its sender is the cryptographically attested sender of
the message, and should be trusted over the sender field of the event.