SupportedAuthScheme

Trait SupportedAuthScheme 

pub trait SupportedAuthScheme: AuthScheme {
    // Required method
    fn authentication_input(
        access_token: SendAccessToken<'_>,
    ) -> Self::Input<'_>;
}
Marker trait to identify the authentication schemes that the Client supports.

This trait can also be implemented for custom [AuthScheme]s if necessary.

Required Methods

fn authentication_input(access_token: SendAccessToken<'_>) -> Self::Input<'_>

Get the [AuthScheme::Input] from the access token.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl SupportedAuthScheme for AccessToken

Source

fn authentication_input(access_token: SendAccessToken<'_>) -> Self::Input<'_>

Source

impl SupportedAuthScheme for AccessTokenOptional

Source

fn authentication_input(access_token: SendAccessToken<'_>) -> Self::Input<'_>

Source

impl SupportedAuthScheme for AppserviceToken

Source

fn authentication_input(access_token: SendAccessToken<'_>) -> Self::Input<'_>

Source

impl SupportedAuthScheme for AppserviceTokenOptional

Source

fn authentication_input(access_token: SendAccessToken<'_>) -> Self::Input<'_>

Source

impl SupportedAuthScheme for NoAccessToken

Source

fn authentication_input(access_token: SendAccessToken<'_>) -> Self::Input<'_>

Source

impl SupportedAuthScheme for NoAuthentication

Source

fn authentication_input(_access_token: SendAccessToken<'_>) -> Self::Input<'_>

Implementors