SupportedPathBuilder

Trait SupportedPathBuilder 

pub trait SupportedPathBuilder: PathBuilder {
    // Required method
    fn get_path_builder_input(
        client: &Client,
        skip_auth: bool,
    ) -> impl Future<Output = HttpResult<Self::Input<'static>>> + SendOutsideWasm;
}
Marker trait to identify the path builders that the Client supports.

This trait can also be implemented for custom PathBuilders if necessary.

Required Methods

fn get_path_builder_input( client: &Client, skip_auth: bool, ) -> impl Future<Output = HttpResult<Self::Input<'static>>> + SendOutsideWasm

Get the PathBuilder::Input from the Client.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl SupportedPathBuilder for SinglePath

Source

async fn get_path_builder_input( _client: &Client, _skip_auth: bool, ) -> HttpResult<()>

Source

impl SupportedPathBuilder for VersionHistory

Source

async fn get_path_builder_input( client: &Client, skip_auth: bool, ) -> HttpResult<Cow<'static, SupportedVersions>>

Implementors