pub enum CallIntentConsensus {
Full(CallIntent),
Partial {
intent: CallIntent,
agreeing_count: u64,
total_count: u64,
},
None,
}Expand description
Represents the consensus state of call intent among room members. Call members can advertise their intent to use audio or video, clients can use this in the UI and also to decide to start camera or not when joining.
This enum distinguishes between full consensus (all members advertise and agree), partial consensus (only some members advertise, but those who do agree), and no consensus (either no one advertises or advertisers disagree).
Variants
Full(CallIntent)
All members advertise and agree
Partial
Some members advertise and agree
Fields

intent: CallIntentThe call intent that advertising members agree on.
None
No consensus. No one advertises or advertisers disagree.