Struct OwnedServerName
pub struct OwnedServerName { /* private fields */ }Expand description
Owned variant of ServerName
Inner representation
By default, this type uses a Box<str> internally. The inner representation can be selected at
compile time by using one of the following supported values:
Arc– Use anArc<str>.
The selected value can be set by using the ruma_identifiers_storage compile-time cfg setting.
This setting can be configured using the RUSTFLAGS environment variable at build time, like this:
RUSTFLAGS="--cfg ruma_identifiers_storage=\"{value}\""Or in .cargo/config.toml:
# General setting for all targets, overridden by per-target `rustflags` setting if set.
[build]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]
# Per-target setting.
[target.<triple/cfg>]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]This setting can also be configured using the RUMA_IDENTIFIERS_STORAGE environment variable at
compile time, which has the benefit of not requiring to re-compile the whole dependency chain
when the value is changed, like this:
RUMA_IDENTIFIERS_STORAGE="{value}"Methods from Deref<Target = ServerName>
pub fn host(&self) -> &str
pub fn host(&self) -> &str
Returns the host of the server name.
That is: Return the part of the server name before :<port> or the full server name if
there is no port.
pub fn is_ip_literal(&self) -> bool
pub fn is_ip_literal(&self) -> bool
Returns true if and only if the server name is an IPv4 or IPv6 address.