pub trait SupportedAuthScheme: AuthScheme {
// Required method
fn authentication_input(
access_token: SendAccessToken<'_>,
) -> Self::Input<'_>;
}Expand description
Marker trait to identify the authentication schemes that the
Client supports.
This trait can also be implemented for custom AuthSchemes if necessary.
Required Methods
Sourcefn authentication_input(access_token: SendAccessToken<'_>) -> Self::Input<'_>
fn authentication_input(access_token: SendAccessToken<'_>) -> Self::Input<'_>
Get the AuthScheme::Input from the access token.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.